;------------------------------------------------------------
;------------------------------------------------------------
;------------------------------------------------------------
;
; NAME: make_geogrid.pro
;
; PURPOSE: Creates for a given ORCA grid, ORCA_GEO which is
; the closest geographical grid to this ORCA grid
;
; CATEGORY : Subroutine
;
; CALLING SEQUENCE : make_geogrid
;
; INPUTS :
;         All the variables of a given ORCA meshmask file
; OUTPUTS :
;         A netcdf format meshmask file that has the same size as the
;         one given in input and contains exactly the same variable,
;         although they describe another grid.
;
; COMMON BLOCKS:
;         None
;
; SIDE EFFECTS:
;
; RESTRICTIONS:
;
; EXAMPLE:
;
; MODIFICATION HISTORY: 08/2002 Robinson Hordoir
;
;------------------------------------------------------------
;------------------------------------------------------------
;------------------------------------------------------------


pro make_geogrid

@initorca
@init_path2
@naminterp2

;------------------------------------------------------------
; Creation of a regular grid based on a given ORCA grid
;------------------------------------------------------------


;******************************************
; 0. DEFINE OUTPUT VALUES
;******************************************


; Output values are set to input values

  glamt_reg=glamt
  glamu_reg=glamu
  glamv_reg=glamv
  glamf_reg=glamf

  gphit_reg=gphit
  gphiu_reg=gphiu
  gphiv_reg=gphiv
  gphif_reg=gphif

  e1t_reg=e1t
  e1u_reg=e1u
  e1v_reg=e1v
  e1f_reg=e1f

  e2t_reg=e2t
  e2u_reg=e2u
  e2v_reg=e2v
  e2f_reg=e2f
  
  tmask_reg=tmask
  umask_reg=tmask
  vmask_reg=tmask
  fmask_reg=tmask


;*****************************************************************
; 1. FIRST STEP : DEFINE  THE LATITUDE, LONGITUDE & SCALE FACTORS
;*****************************************************************

; Let's get our reference latitude. Search for northernmost place
; of the ORCA grid that is still geographical

northernmost=where(gphit EQ max(gphit))

jnorth=northernmost/jpi

inorth=min(northernmost-jnorth*jpi)

ref_latitude=gphit(inorth,*)

; Let's get the reference longitude

equador=where(abs(gphit) EQ  min(abs(gphit)) )

ref_longitude=glamt(equador)

; Duplication for all T points

glamt_reg=ref_longitude#replicate(1,n_elements(ref_latitude))


gphit_reg=replicate(1,n_elements(ref_longitude))#ref_latitude

; COMPUTATION OF LONGITUDES AND LATITUDES AT ALL POINTS

; From this we can deduce glamu_reg and gphiu_reg

glamu_reg=glamt_reg+grid_def/2.
gphiu_reg=gphit_reg

; As well as glamv_reg and gphiv_reg

glamv_reg=glamt_reg
gphiv_reg=gphit_reg+(gphit_reg-shift(gphit_reg,0,-1))/2.
gphiv_reg(*,jpj-1)=gphit_reg(*,jpj-1)+(gphit_reg(*,jpj-1)-gphit_reg(*,jpj-2))/2.

; Same thing for glamf_reg and gphif_reg

glamf_reg=glamu_reg
gphif_reg=gphiv_reg


; COMPUTATION OF SCALE FACTORS



; Scale factor at equator

eq_j=where(gphit(inorth,*) EQ 0.)

e1t_eq=e1t(*,eq_j)

; E1t scale factor

e1t_reg=( e1t_eq#replicate(1.,jpj) )*(replicate(1.,jpi)#cos(!PI*gphit(inorth,*)/180.))


; E2t scale factor

e2t_reg=replicate(1.,jpi)#e2t(inorth,*)


; E1u scale factor
; e1u_reg=e1t_reg because the grid is fully regular along x axis
; Same remark for e2u

e1u_reg=e1t_reg
e2u_reg=e2t_reg

;E1v scale factor

e1v_reg=( e1t_eq#replicate(1.,jpj) )*(replicate(1.,jpi)#cos(!PI*gphiv(inorth,*)/180.))

; E2v scale factor

e2v_reg=replicate(1.,jpi)#e2v(inorth,*)

;E1f scale factor

e1f_reg=( e1t_eq#replicate(1.,jpj) )*(replicate(1.,jpi)#cos(!PI*gphit(inorth,*)/180.))

;E2f scale factor

e2f_reg=replicate(1.,jpi)#e2f(inorth,*)


;************************************************
;  2nd STEP : Define the mask of the outpt grid
;************************************************


; We now need to define the grid mask...


mask_reg=tmask

; Let's get entire coordinates of meshmask


sph_coord=replicate(1.,3,jpi*jpj)

; We put some crazy values of radius on half of the North Fold line in order
; to avoid any problem

sph_coord(2,jpj*jpi-1-jpi/2:jpj*jpi-1)=10. 

sph_coord(0,*)=reform(glamt,jpi*jpj)
sph_coord(1,*)=reform(gphit,jpi*jpj)

rec_grid=cv_coord(/DEGREES,FROM_SPHERE=sph_coord,/TO_RECT)

xx_grid=rec_grid(0,*)
yy_grid=rec_grid(1,*)   
zz_grid=rec_grid(2,*)
  

not_found=1
for jj=0, jpj-1 do begin

   lat_max_ORCA=max( gphit(*,jj)     )
   lat_max_reg =max( gphit_reg(*,jj) )


   if ((lat_max_ORCA NE lat_max_reg) AND (not_found EQ 1)) then begin
   jpj_start=jj-2
   not_found=0
   endif

end



; Loop on all elements of our geo grid

for jj=jpj/2,jpj-1 do begin
    for ji=0,jpi-1 do begin
   

; Coordinates of our point

    xx=glamt_reg(ji,jj)
    yy=gphit_reg(ji,jj)
   
    sph_coord=replicate(1.,3)
    sph_coord(0)=xx
    sph_coord(1)=yy

; Convert them into cartesian 
    
    rec_coord=cv_coord(/DEGREES,FROM_SPHERE=sph_coord,/TO_RECT)

    xx_bis=replicate(rec_coord(0),jpi*jpj)
    yy_bis=replicate(rec_coord(1),jpi*jpj)
    zz_bis=replicate(rec_coord(2),jpi*jpj)

    modules=sqrt((xx_grid-xx_bis)*(xx_grid-xx_bis)  $
                +(yy_grid-yy_bis)*(yy_grid-yy_bis)  $
                +(zz_grid-zz_bis)*(zz_grid-zz_bis))
    

    sort_mod=where(modules EQ min(modules))

    answj=sort_mod(0)/jpi   

    answi=sort_mod(0)-answj*jpi


    mask_reg(ji,jj,*)=tmask(answi,answj,*)
    
 
    endfor
endfor

;*****************************************
; 3rd STEP : PUT VALUES INTO ATTRIBUTES
;*****************************************

;********** T MASK*********************

; Create Global Mask file for T point

    tmask_reg_glo=replicate(0.,jpiglo,jpjglo,jpk)

    tmask_reg_glo(1:jpiglo-2,0:jpjglo-2, *)=mask_reg


; Data Duplication

; North

    tmask_reg_glo(*,jpjglo-1,*)=tmask_reg_glo(*,jpjglo-2,*)
;E/W

    tmask_reg_glo(0,*,*)=tmask_reg_glo(jpiglo-2,*,*)
    tmask_reg_glo(jpiglo-1,*,*)=tmask_reg_glo(1,*,*)

; Global T mask in created

; Creates U mask, V mask and F mask


   umask_reg=tmask_reg_glo(1:jpiglo-2,0:jpjglo-2,*)*tmask_reg_glo(2:jpiglo-1,0:jpjglo-2,*)

   vmask_reg=tmask_reg_glo(1:jpiglo-2,0:jpjglo-2,*)*tmask_reg_glo(1:jpiglo-2,1:jpjglo-1,*)

   fmask_reg=tmask_reg_glo(1:jpiglo-2,0:jpjglo-2,*)*tmask_reg_glo(2:jpiglo-1,0:jpjglo-2,*) $
            *tmask_reg_glo(1:jpiglo-2,1:jpjglo-1,*)*tmask_reg_glo(2:jpiglo-1,1:jpjglo-1,*)

; Create Global Mask file for U,V & F points

    umask_reg_glo=replicate(0.,jpiglo,jpjglo,jpk)
    umask_reg_glo(1:jpiglo-2,0:jpjglo-2, *)=umask_reg

    vmask_reg_glo=replicate(0.,jpiglo,jpjglo,jpk)
    vmask_reg_glo(1:jpiglo-2,0:jpjglo-2, *)=vmask_reg

    fmask_reg_glo=replicate(0.,jpiglo,jpjglo,jpk)
    fmask_reg_glo(1:jpiglo-2,0:jpjglo-2, *)=fmask_reg

; Data Duplication

; North

    umask_reg_glo(*,jpjglo-1,*)=umask_reg_glo(*,jpjglo-2,*)
    vmask_reg_glo(*,jpjglo-1,*)=vmask_reg_glo(*,jpjglo-2,*)
    fmask_reg_glo(*,jpjglo-1,*)=fmask_reg_glo(*,jpjglo-2,*)

;E/W

    umask_reg_glo(0,*,*)=umask_reg_glo(jpiglo-2,*,*)
    umask_reg_glo(jpiglo-1,*,*)=umask_reg_glo(1,*,*)

    vmask_reg_glo(0,*,*)=vmask_reg_glo(jpiglo-2,*,*)
    vmask_reg_glo(jpiglo-1,*,*)=vmask_reg_glo(1,*,*)

    fmask_reg_glo(0,*,*)=fmask_reg_glo(jpiglo-2,*,*)
    fmask_reg_glo(jpiglo-1,*,*)=fmask_reg_glo(1,*,*)

; ***** NAV_LON & NAV_LAT **********


; Create Global longitude and latitude

    glamt_reg_glo=replicate(0.,jpiglo,jpjglo)

    glamt_reg_glo(1:jpiglo-2,0:jpjglo-2)=glamt_reg

    gphit_reg_glo=replicate(0.,jpiglo,jpjglo)

    gphit_reg_glo(1:jpiglo-2,0:jpjglo-2)=gphit_reg

    nav_lon_reg_glo=replicate(0.,jpiglo,jpjglo)

    nav_lat_reg_glo=replicate(0.,jpiglo,jpjglo)

    nav_lon_reg_glo=glamt_reg_glo

    nav_lat_reg_glo=gphit_reg_glo

; Data Duplication

; E/W Transition

    nav_lon_reg_glo(0,*)=nav_lon_reg_glo(jpiglo-2,*)
    nav_lon_reg_glo(jpiglo-1,*)=nav_lon_reg_glo(1,*)

    nav_lat_reg_glo(0,*)=nav_lat_reg_glo(jpiglo-2,*)
    nav_lat_reg_glo(jpiglo-1,*)=nav_lat_reg_glo(1,*)

; North

    nav_lon_reg_glo(*,jpjglo-1)= nav_lon_reg_glo(*,jpjglo-2)
    nav_lat_reg_glo(*,jpjglo-1)= nav_lat_reg_glo(*,jpjglo-2)

; ***** GLAMT *****
; We don't do it to save memory :  same as nav_lon 

; ***** GLAMU *****

    glamu_reg_glo=replicate(0.,jpiglo,jpjglo)
    glamu_reg_glo(1:jpiglo-2,0:jpjglo-2)=glamu_reg

; North

    glamu_reg_glo(*,jpjglo-1)=glamu_reg_glo(*,jpjglo-2)
    
; E/W
 
    glamu_reg_glo(0,*)=glamu_reg_glo(jpiglo-2,*)
    glamu_reg_glo(jpiglo-1,*)=glamu_reg_glo(1,*)
    
; ***** GLAMV *****

    glamv_reg_glo=replicate(0.,jpiglo,jpjglo)
    glamv_reg_glo(1:jpiglo-2,0:jpjglo-2)=glamv_reg

; North

    glamv_reg_glo(*,jpjglo-1)=glamv_reg_glo(*,jpjglo-2)
    
; E/W
 
    glamv_reg_glo(0,*)=glamv_reg_glo(jpiglo-2,*)
    glamv_reg_glo(jpiglo-1,*)=glamv_reg_glo(1,*)


; ***** GLAMF *****

    glamf_reg_glo=replicate(0.,jpiglo,jpjglo)
    glamf_reg_glo(1:jpiglo-2,0:jpjglo-2)=glamf_reg

; North

    glamf_reg_glo(*,jpjglo-1)=glamf_reg_glo(*,jpjglo-2)
    
; E/W
 
    glamf_reg_glo(0,*)=glamf_reg_glo(jpiglo-2,*)
    glamf_reg_glo(jpiglo-1,*)=glamf_reg_glo(1,*)


; ***** GPHIT *****
; We don't do it to save memory :  same as nav_lat 

; ***** GPHIU *****

    gphiu_reg_glo=replicate(0.,jpiglo,jpjglo)
    gphiu_reg_glo(1:jpiglo-2,0:jpjglo-2)=gphiu_reg

; North

    gphiu_reg_glo(*,jpjglo-1)=gphiu_reg_glo(*,jpjglo-2)
    
; E/W
 
    gphiu_reg_glo(0,*)=gphiu_reg_glo(jpiglo-2,*)
    gphiu_reg_glo(jpiglo-1,*)=gphiu_reg_glo(1,*)
    
; ***** GPHIV *****

    gphiv_reg_glo=replicate(0.,jpiglo,jpjglo)
    gphiv_reg_glo(1:jpiglo-2,0:jpjglo-2)=gphiv_reg

; North

    gphiv_reg_glo(*,jpjglo-1)=gphiv_reg_glo(*,jpjglo-2)
    
; E/W
 
    gphiv_reg_glo(0,*)=gphiv_reg_glo(jpiglo-2,*)
    gphiv_reg_glo(jpiglo-1,*)=gphiv_reg_glo(1,*)


; ***** GPHIF *****

    gphif_reg_glo=replicate(0.,jpiglo,jpjglo)
    gphif_reg_glo(1:jpiglo-2,0:jpjglo-2)=gphif_reg

; North

    gphif_reg_glo(*,jpjglo-1)=gphif_reg_glo(*,jpjglo-2)
    
; E/W
 
    gphif_reg_glo(0,*)=gphif_reg_glo(jpiglo-2,*)
    gphif_reg_glo(jpiglo-1,*)=gphif_reg_glo(1,*)

; ***** FF *******

    omega = 2.0 * !PI / 86164.0
    
    ff_reg_glo = 2.*omega*sin(gphif_reg_glo*!PI/180.) 
    

; *********** E1T***************
    
    e1t_reg_glo=replicate(0.,jpiglo,jpjglo)
    e1t_reg_glo(1:jpiglo-2,0:jpjglo-2)=e1t_reg

; North

    e1t_reg_glo(*,jpjglo-1)=e1t_reg_glo(*,jpjglo-2)
    
; E/W
 
    e1t_reg_glo(0,*)=e1t_reg_glo(jpiglo-2,*)
    e1t_reg_glo(jpiglo-1,*)=e1t_reg_glo(1,*)



; *********** E2T***************
    
    e2t_reg_glo=replicate(0.,jpiglo,jpjglo)
    e2t_reg_glo(1:jpiglo-2,0:jpjglo-2)=e2t_reg

; North

    e2t_reg_glo(*,jpjglo-1)=e2t_reg_glo(*,jpjglo-2)
    
; E/W
 
    e2t_reg_glo(0,*)=e2t_reg_glo(jpiglo-2,*)
    e2t_reg_glo(jpiglo-1,*)=e2t_reg_glo(1,*)

; *********** E1U***************
    
    e1u_reg_glo=replicate(0.,jpiglo,jpjglo)
    e1u_reg_glo(1:jpiglo-2,0:jpjglo-2)=e1u_reg

; North

    e1u_reg_glo(*,jpjglo-1)=e1u_reg_glo(*,jpjglo-2)
    
; E/W
 
    e1u_reg_glo(0,*)=e1u_reg_glo(jpiglo-2,*)
    e1u_reg_glo(jpiglo-1,*)=e1u_reg_glo(1,*)


; *********** E2U***************
    
    e2u_reg_glo=replicate(0.,jpiglo,jpjglo)
    e2u_reg_glo(1:jpiglo-2,0:jpjglo-2)=e2u_reg

; North

    e2u_reg_glo(*,jpjglo-1)=e2u_reg_glo(*,jpjglo-2)
    
; E/W
 
    e2u_reg_glo(0,*)=e2u_reg_glo(jpiglo-2,*)
    e2u_reg_glo(jpiglo-1,*)=e2u_reg_glo(1,*)

; *********** E1V***************
    
    e1v_reg_glo=replicate(0.,jpiglo,jpjglo)
    e1v_reg_glo(1:jpiglo-2,0:jpjglo-2)=e1v_reg

; North

    e1v_reg_glo(*,jpjglo-1)=e1v_reg_glo(*,jpjglo-2)
    
; E/W
 
    e1v_reg_glo(0,*)=e1v_reg_glo(jpiglo-2,*)
    e1v_reg_glo(jpiglo-1,*)=e1v_reg_glo(1,*)

; *********** E2V***************
    
    e2v_reg_glo=replicate(0.,jpiglo,jpjglo)
    e2v_reg_glo(1:jpiglo-2,0:jpjglo-2)=e2v_reg

; North

    e2v_reg_glo(*,jpjglo-1)=e2v_reg_glo(*,jpjglo-2)
    
; E/W
 
    e2v_reg_glo(0,*)=e2v_reg_glo(jpiglo-2,*)
    e2v_reg_glo(jpiglo-1,*)=e2v_reg_glo(1,*)

; *********** E1F **************

    e1f_reg_glo=replicate(0.,jpiglo,jpjglo)
    e1f_reg_glo(1:jpiglo-2,0:jpjglo-2)=e1f_reg

; North

    e1f_reg_glo(*,jpjglo-1)=e1f_reg_glo(*,jpjglo-2)
    
; E/W
 
    e1f_reg_glo(0,*)=e1f_reg_glo(jpiglo-2,*)
    e1f_reg_glo(jpiglo-1,*)=e1f_reg_glo(1,*)

; *********** E2F***************
    
    e2f_reg_glo=replicate(0.,jpiglo,jpjglo)
    e2f_reg_glo(1:jpiglo-2,0:jpjglo-2)=e2f_reg

; North

    e2f_reg_glo(*,jpjglo-1)=e2f_reg_glo(*,jpjglo-2)
    
; E/W
 
    e2f_reg_glo(0,*)=e2f_reg_glo(jpiglo-2,*)
    e2f_reg_glo(jpiglo-1,*)=e2f_reg_glo(1,*)



;****************END OF ATTRIBUTES****************

 
;*************************************************
; 4th STEP : CREATES NCDF MESHMASK FILE
;*************************************************

; Creates Netcdf File to save this


   vargrid = 'T'

; Name
   idout = NCDF_CREATE(outputgrid,/clobber)
   print, 'Creation du fichier Netcdf'
   NCDF_CONTROL, idout, /nofill
; Dimension

   xidout = NCDF_DIMDEF(idout, 'x', jpiglo)
   yidout = NCDF_DIMDEF(idout, 'y', jpjglo)
   didout = NCDF_DIMDEF(idout, 'z', jpk)
   x_a    = NCDF_DIMDEF(idout, 'x_a',1)
   y_a    = NCDF_DIMDEF(idout, 'y_a',1)
   z_a    = NCDF_DIMDEF(idout, 'z_a',1)
   tidout = NCDF_DIMDEF(idout, 'time_counter', /unlimited)

; Attributes
     
   id0  = NCDF_VARDEF(idout, 'nav_lon'     , [xidout, yidout                ],/FLOAT )
   id1  = NCDF_VARDEF(idout, 'nav_lat'     , [xidout, yidout                ],/FLOAT )
   id2  = NCDF_VARDEF(idout, 'nav_lev'     , [                didout        ],/FLOAT )
   id3  = NCDF_VARDEF(idout, 'time'        , [                        tidout],/FLOAT )
   id4  = NCDF_VARDEF(idout, 'time_steps'  , [                        tidout],/LONG  )
   id5  = NCDF_VARDEF(idout, 'glamt'       , [xidout, yidout, z_a   , tidout],/DOUBLE)
   id6  = NCDF_VARDEF(idout, 'glamu'       , [xidout, yidout, z_a   , tidout],/DOUBLE)
   id7  = NCDF_VARDEF(idout, 'glamv'       , [xidout, yidout, z_a   , tidout],/DOUBLE)
   id8  = NCDF_VARDEF(idout, 'glamf'       , [xidout, yidout, z_a   , tidout],/DOUBLE)
   id9  = NCDF_VARDEF(idout, 'gphit'       , [xidout, yidout, z_a   , tidout],/DOUBLE)
   id10 = NCDF_VARDEF(idout, 'gphiu'       , [xidout, yidout, z_a   , tidout],/DOUBLE)
   id11 = NCDF_VARDEF(idout, 'gphiv'       , [xidout, yidout, z_a   , tidout],/DOUBLE)
   id12 = NCDF_VARDEF(idout, 'gphif'       , [xidout, yidout, z_a   , tidout],/DOUBLE)
   id13 = NCDF_VARDEF(idout, 'e1t'         , [xidout, yidout, z_a   , tidout],/DOUBLE)
   id14 = NCDF_VARDEF(idout, 'e1u'         , [xidout, yidout, z_a   , tidout],/DOUBLE)
   id15 = NCDF_VARDEF(idout, 'e1v'         , [xidout, yidout, z_a   , tidout],/DOUBLE)
   id16 = NCDF_VARDEF(idout, 'e1f'         , [xidout, yidout, z_a   , tidout],/DOUBLE)
   id17 = NCDF_VARDEF(idout, 'e2t'         , [xidout, yidout, z_a   , tidout],/DOUBLE)
   id18 = NCDF_VARDEF(idout, 'e2u'         , [xidout, yidout, z_a   , tidout],/DOUBLE)
   id19 = NCDF_VARDEF(idout, 'e2v'         , [xidout, yidout, z_a   , tidout],/DOUBLE)
   id20 = NCDF_VARDEF(idout, 'e2f'         , [xidout, yidout, z_a   , tidout],/DOUBLE)
   id21 = NCDF_VARDEF(idout, 'tmask'       , [xidout, yidout, didout, tidout],/DOUBLE)
   id22 = NCDF_VARDEF(idout, 'umask'       , [xidout, yidout, didout, tidout],/DOUBLE)
   id23 = NCDF_VARDEF(idout, 'vmask'       , [xidout, yidout, didout, tidout],/DOUBLE)
   id24 = NCDF_VARDEF(idout, 'fmask'       , [xidout, yidout, didout, tidout],/DOUBLE)
   id25 = NCDF_VARDEF(idout, 'ff'          , [xidout, yidout, z_a   , tidout],/DOUBLE)
   id26 = NCDF_VARDEF(idout, 'gdept'       , [x_a   , y_a   , didout, tidout],/DOUBLE)
   id27 = NCDF_VARDEF(idout, 'gdepw'       , [x_a   , y_a   , didout, tidout],/DOUBLE)
   id28 = NCDF_VARDEF(idout, 'e3t'         , [x_a   , y_a   , didout, tidout],/DOUBLE)
   id29 = NCDF_VARDEF(idout, 'e3w'         , [x_a   , y_a   , didout, tidout],/DOUBLE)

; Variable 0
   NCDF_ATTPUT, idout, id0, 'units', 'degrees_east'
   NCDF_ATTPUT, idout, id0, 'long_name', 'Longitude'
   NCDF_ATTPUT, idout, id0, 'nav_model', 'Default grid'
; Variable 1
   NCDF_ATTPUT, idout, id1, 'units', 'degrees_north'
   NCDF_ATTPUT, idout, id1, 'long_name', 'Latitude'
   NCDF_ATTPUT, idout, id1, 'nav_model', 'Default grid'
; Variable 2
   NCDF_ATTPUT, idout, id2, 'units','meters'
   NCDF_ATTPUT, idout, id2, 'long_name','Depth'
   NCDF_ATTPUT, idout, id2, 'nav_model','Default grid'
; Variable 3
   NCDF_ATTPUT, idout, id3, 'units', 'seconds since 0001-01-15 12:00:00 '
   NCDF_ATTPUT, idout, id3, 'calendar','noleap'
   NCDF_ATTPUT, idout, id3, 'title', 'Time'
   NCDF_ATTPUT, idout, id3, 'long_name', 'Time axis'
   NCDF_ATTPUT, idout, id3, 'time_origin','0000-DEC-15 00:00:00'

  
   NCDF_CONTROL, idout, /ENDEF



; Writting


   NCDF_VARPUT, idout, id0 , nav_lon_reg_glo
   NCDF_VARPUT, idout, id1 , nav_lat_reg_glo
   NCDF_VARPUT, idout, id2 , gdept
   NCDF_VARPUT, idout, id3 , 1.
   NCDF_VARPUT, idout, id4 , 1.
   NCDF_VARPUT, idout, id5 , nav_lon_reg_glo

   NCDF_VARPUT, idout, id6 , glamu_reg_glo
   NCDF_VARPUT, idout, id7 , glamv_reg_glo
   NCDF_VARPUT, idout, id8 , glamf_reg_glo
   NCDF_VARPUT, idout, id9 , nav_lat_reg_glo
   NCDF_VARPUT, idout, id10, gphiu_reg_glo
   NCDF_VARPUT, idout, id11, gphiv_reg_glo
   NCDF_VARPUT, idout, id12, gphif_reg_glo
   NCDF_VARPUT, idout, id13, e1t_reg_glo
   NCDF_VARPUT, idout, id14, e1u_reg_glo
   NCDF_VARPUT, idout, id15, e1v_reg_glo
   NCDF_VARPUT, idout, id16, e1f_reg_glo
   NCDF_VARPUT, idout, id17, e2t_reg_glo
   NCDF_VARPUT, idout, id18, e2u_reg_glo
   NCDF_VARPUT, idout, id19, e2v_reg_glo
   NCDF_VARPUT, idout, id20, e2f_reg_glo
   NCDF_VARPUT, idout, id21, tmask_reg_glo
   NCDF_VARPUT, idout, id22, umask_reg_glo
   NCDF_VARPUT, idout, id23, vmask_reg_glo
   NCDF_VARPUT, idout, id24, fmask_reg_glo
   NCDF_VARPUT, idout, id25, ff_reg_glo

   dummy=replicate(0.,1,1,jpk,1)
   dummy(0,0,*,0)=gdept

   NCDF_VARPUT, idout, id26, dummy

    dummy=replicate(0.,1,1,jpk,1)
    dummy(0,0,*,0)=gdepw

   NCDF_VARPUT, idout, id27, dummy

    dummy=replicate(0.,1,1,jpk,1)
    dummy(0,0,*,0)=e3t

   NCDF_VARPUT, idout, id28, dummy

    dummy=replicate(0.,1,1,jpk,1)
    dummy(0,0,*,0)=e3w

   NCDF_VARPUT, idout, id29, dummy

   NCDF_CLOSE, idout

   

end

